
# StruVolPy <img src="https://github.com/hllelli2/struvolpy/blob/main/.logo.png" width="100" align="right">

[![Pytest](https://github.com/hllelli2/struvolpy/actions/workflows/run_test.yml/badge.svg)](https://github.com/hllelli2/struvolpy/actions/workflows/run_test.yml?event=push)


\
\
The StruVolpy package provides parsers for structural biology data formats, atomic coordinates files and electron density maps. This package is designed to help developers working with structural biology data to easily read and manipulate these types of files. The package also includes installation instructions and related projects.






## Installation

Install struvolpy with pip (hopefully soon)

```
pip install struvolpy
```
    
## Related

Here are some projects that use StruVolPy:


[SliceNDice]()

[PowerFit37]()

*Links added soon*


## License

[GPLv3](https://www.gnu.org/licenses/gpl-3.0.en.html)
